@@ -2,8 +2,8 @@
  *  parser.h - argument parser & dispatcher module - header 
  * 
  *  nc6 - an advanced netcat clone
- *  Copyright (C) 2001-2003 Mauro Tortonesi <mauro _at_ deepspace6.net>
- *  Copyright (C) 2002-2003 Chris Leishman <chris _at_ leishman.org>
+ *  Copyright (C) 2001-2006 Mauro Tortonesi <mauro _at_ deepspace6.net>
+ *  Copyright (C) 2002-2006 Chris Leishman <chris _at_ leishman.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,11 +23,10 @@
 #define PARSER_H
 
 #include "connection.h"
-#include "misc.h"
 
 bool verbose_mode(void);
 bool very_verbose_mode(void);
 
-void parse_arguments(int argc, char **argv, connection_attributes *attrs);
+void parse_arguments(int argc, char **argv, connection_attributes_t *attrs);
 
-#endif /* PARSER_H */
+#endif/*PARSER_H*/
