@@ -2,8 +2,8 @@
  *  readwrite.h - stream i/o reading/writing loop - header
  * 
  *  nc6 - an advanced netcat clone
- *  Copyright (C) 2001-2003 Mauro Tortonesi <mauro _at_ deepspace6.net>
- *  Copyright (C) 2002-2003 Chris Leishman <chris _at_ leishman.org>
+ *  Copyright (C) 2001-2006 Mauro Tortonesi <mauro _at_ deepspace6.net>
+ *  Copyright (C) 2002-2006 Chris Leishman <chris _at_ leishman.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,6 @@
 
 #include "io_stream.h"
 
-int readwrite(io_stream *ios1, io_stream *ios2);
+int readwrite(io_stream_t *ios1, io_stream_t *ios2);
 
-#endif /* READWRITE_H */
+#endif/*READWRITE_H*/
